==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/SnmpTrapEJB/src/com/clustercontrol/snmptrap/factory/AddMonitorInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.jms.JMSException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;
import javax.transaction.TransactionManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoUtil;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapInfo;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapOidInfo;
import com.clustercontrol.snmptrap.bean.TopicConstant;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapInfoUtil;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterUtil;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapOidInfoUtil;
import com.clustercontrol.snmptrap.message.UpdateSnmpTrapInfo;
import com.clustercontrol.snmptrap.util.SendTopic;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * 監視情報を登録するクラス<BR>
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class AddMonitorInfo {
	
	protected static Log m_log = LogFactory.getLog( AddMonitorInfo.class );
	
	/** 監視情報ビーン */
	protected MonitorSnmpTrapInfo m_monitorInfo;
	
	/**
	 * 監視情報を登録します。<BR>
	 * 
	 * @param info 監視情報
	 * @param user ユーザ
	 * @return 登録に成功した場合、true
	 * @throws CreateException
	 * @throws NotSupportedException
	 * @throws RollbackException
	 * @throws HeuristicMixedException
	 * @throws HeuristicRollbackException
	 * @throws SystemException
	 * @throws InvalidTransactionException
	 * @throws NamingException
	 * @throws FinderException 
	 */
	public boolean add(MonitorSnmpTrapInfo info, String user) throws CreateException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException, InvalidTransactionException, NamingException, FinderException {
		
    	//アクセスロック
    	AccessLock.lock(AccessLock.MONITOR_SNMPTRAP);

		m_monitorInfo = info;
		
		TransactionManager tm = null;
		Transaction tx = null;
		Transaction oldTx = null;
		boolean result = false;
		
		try 
		{
			// TransactionManagerを取得
			InitialContext context = new InitialContext();
			tm = (TransactionManager)context.lookup("java:/TransactionManager");
			
			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避 
			if(tm.getTransaction() != null){
				oldTx = tm.suspend();
			}
			
			try{
				// トランザクション開始
				if(tm.getTransaction() == null){
					tm.begin();	
					tx = tm.getTransaction();
				}
				
				// 監視情報を登録
				result = addMonitorInfo(user);
				if(result){
					// コミット
					tx.commit();
				}
				
				try {
					// 更新通知
					UpdateSnmpTrapInfo updateInfo = new UpdateSnmpTrapInfo(
							UpdateSnmpTrapInfo.TYPE_ADD,
							info.getMonitorId());
					
					SendTopic sendTopic = new SendTopic(TopicConstant.TOPIC_NAME_UPDATE);
					sendTopic.put(updateInfo);
					
				} catch (NamingException e) {
					m_log.error("add() : 送信エラー。" + e.getMessage() );
				} catch (JMSException e) {
					m_log.error("add() : 送信エラー。" + e.getMessage() );
				}
			
			} catch(NotSupportedException e){
				outputLog(e, "add()");
				throw e;
			} catch (RollbackException e) {
				outputLog(e, "add()");
				throw e;
			} catch (HeuristicMixedException e) {
				outputLog(e, "add()");
				throw e;
			} catch(HeuristicRollbackException e){
				outputLog(e, "add()");
				throw e;
			} catch(SystemException e){
				outputLog(e, "add()");
				throw e;
			}
			finally{
				// トランザクション関連の例外が発生した場合は、ロールバック
				if(tx != null){
					if(!result){
						tx.rollback();
					}
					tx = null;
				}
			}
		}
		finally{
			
			// 一時停止していたトランザクションを再開
			if(oldTx != null){
				try{
					tm.resume(oldTx);
				
				} catch(InvalidTransactionException e){
					outputLog(e, "add()");
					throw e;
				} catch(IllegalStateException e){
					outputLog(e, "add()");
					throw e;
				} catch(SystemException e){
					outputLog(e, "add()");
					throw e;
				}
			}
		}
		return result;
	}

	/**
	 * 監視情報を登録します。<BR>
	 * 
	 * @param user ユーザ
	 * @return 登録に成功した場合、true
	 * @throws CreateException
	 * @throws NamingException
	 * @throws FinderException 
	 */
	public boolean addMonitorInfo(String user) throws CreateException, NamingException, FinderException {
		boolean result = false;
		
		try 
		{
			Timestamp now = new Timestamp(new Date().getTime());
			
			m_log.trace("addMonitorInfo  : m_monitorInfo.getCheckMode() " + m_monitorInfo.getCheckMode());
			// 監視情報を挿入
			SnmpTrapInfoUtil.getLocalHome().create(
					m_monitorInfo.getMonitorId(),
					m_monitorInfo.getDescription(),
					m_monitorInfo.getFacilityId(),
					m_monitorInfo.getCommunityName(),
					m_monitorInfo.getNotifyId(),
					m_monitorInfo.getApplication(),
					m_monitorInfo.getValid(),
					m_monitorInfo.getCalendarId(),
					now,
					now,
					user,
					user,
					m_monitorInfo.getCheckMode()
			);
			
			// ジョブ連携のため追加
			// 重要度ごとに実行するジョブの情報を保持するテーブルが必要だが、
			// SNMPトラップ監視機能の設定情報を保持するテーブル cc_snmp_trap_info には、
			// ジョブ連携用の情報を保持するカラムがないため、cc_monitor_infoテーブルと
			// cc_monitor_numeric_value_infoテーブルにその情報を保持する。
			MonitorInfoUtil.getLocalHome().create(
					m_monitorInfo.getMonitorTypeId(),
					m_monitorInfo.getMonitorId(),
					m_monitorInfo.getMonitorType(),
					m_monitorInfo.getDescription(),
					m_monitorInfo.getFacilityId(),
					m_monitorInfo.getRunInterval(),
					m_monitorInfo.getTimeout(),
					m_monitorInfo.getCalendarId(),
					m_monitorInfo.getMonitorBlock(),
					m_monitorInfo.getDeterminationId(),
					m_monitorInfo.getFailurePriority(),
					m_monitorInfo.getNotifyId(),
					m_monitorInfo.getApplication(),
					m_monitorInfo.getJobRun(),
					m_monitorInfo.getFailureMessageId(),
					m_monitorInfo.getFailureMessage(),
					m_monitorInfo.getFailureJobRun(),
					m_monitorInfo.getFailureJobId(),
					m_monitorInfo.getFailureJobInhibitionFlg(),
					m_monitorInfo.getFailureJobFailurePriority(),
					now,
					now,
					user,
					user
					
			);
			
			ArrayList valueList = m_monitorInfo.getJudgementInfo();
			MonitorNumericValueInfo value = null;
			for(int index=0; index<valueList.size(); index++){
				value = (MonitorNumericValueInfo)valueList.get(index);
				if(value != null){
					MonitorNumericValueInfoUtil.getLocalHome().create(
							m_monitorInfo.getMonitorTypeId(),
							m_monitorInfo.getMonitorId(),
							Integer.valueOf(value.getPriority()),
							Double.valueOf(value.getThresholdUpperLimit()),
							Double.valueOf(value.getThresholdLowerLimit()),
							value.getMessageId(),
							value.getMessage(),
							Integer.valueOf(value.getJobRun()),
							value.getJobId(),
							Integer.valueOf(value.getJobInhibitionFlg()),
							Integer.valueOf(value.getJobFailurePriority()));
				}
			}	
			
			if(m_monitorInfo.getOidInfos() != null){
				
				for(int i = 0; i < m_monitorInfo.getOidInfos().size(); i++){
					MonitorSnmpTrapOidInfo oidInfo = m_monitorInfo.getOidInfos().get(i);
					
					SnmpTrapMasterLocal master = 
						SnmpTrapMasterUtil.getLocalHome().findByPrimaryKey(
							new SnmpTrapMasterPK(
									oidInfo.getMib(), 
									oidInfo.getTrapOid(), 
									oidInfo.getGenericId(), 
									oidInfo.getSpecificId()));
					
					//詳細メッセージをマスタの詳細メッセージと比較
					String descr = new String();
					if(oidInfo.getDescr() != null && master.getDescr() != null && 
							!oidInfo.getDescr().equalsIgnoreCase(master.getDescr())){
						if(!oidInfo.getDescr().equalsIgnoreCase(master.getDescr())){
							descr = oidInfo.getDescr();
						}
					}
					else{
						descr = oidInfo.getDescr();
					}
					
					// 監視OID情報を挿入
					SnmpTrapOidInfoUtil.getLocalHome().create(
							oidInfo.getMonitorId(),
							oidInfo.getMib(),
							oidInfo.getTrapOid(),
							new Integer(oidInfo.getGenericId()),
							new Integer(oidInfo.getSpecificId()),
							new Integer(oidInfo.getValidFlg()),
							new Integer(oidInfo.getPriority()),
							oidInfo.getLogmsg(),
							descr
					);
				}
			}
				
			result = true;
			
		} catch (CreateException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		} catch (NamingException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		} catch (FinderException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		}
		
		return result;
	}
	
	/**
     * アプリケーションログにログを出力
     * 
     * @param e 例外
     */
	private void outputLog(Exception e, String method){
		AplLogger apllog = new AplLogger("TRAP", "trap");
		String[] args = {m_monitorInfo.getMonitorId() };
        apllog.put("SYS", "001", args);
        m_log.debug(method + ":" + e.getMessage());
	}
}

==> hinemos_src-3.0.5.tar.gz: Hinemos_src-3.0.5/SnmpTrapEJB/src/com/clustercontrol/snmptrap/factory/AddMonitorInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.jms.JMSException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;
import javax.transaction.TransactionManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapInfo;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapOidInfo;
import com.clustercontrol.snmptrap.bean.TopicConstant;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapInfoUtil;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterUtil;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapOidInfoUtil;
import com.clustercontrol.snmptrap.message.UpdateSnmpTrapInfo;
import com.clustercontrol.snmptrap.util.SendTopic;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * 監視情報を登録するクラス<BR>
 *
 * @version 3.0.0
 * @since 2.1.0
 */
public class AddMonitorInfo {
	
	protected static Log m_log = LogFactory.getLog( AddMonitorInfo.class );
	
	/** 監視情報ビーン */
	protected MonitorSnmpTrapInfo m_monitorInfo;
	
	/**
	 * 監視情報を登録します。<BR>
	 * 
	 * @param info 監視情報
	 * @param user ユーザ
	 * @return 登録に成功した場合、true
	 * @throws CreateException
	 * @throws NotSupportedException
	 * @throws RollbackException
	 * @throws HeuristicMixedException
	 * @throws HeuristicRollbackException
	 * @throws SystemException
	 * @throws InvalidTransactionException
	 * @throws NamingException
	 * @throws FinderException 
	 */
	public boolean add(MonitorSnmpTrapInfo info, String user) throws CreateException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException, InvalidTransactionException, NamingException, FinderException {
		
    	//アクセスロック
    	AccessLock.lock(AccessLock.MONITOR_SNMPTRAP);

		m_monitorInfo = info;
		
		TransactionManager tm = null;
//		Transaction tx = null;
//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama		
		Transaction oldTx = null;
		boolean result = false;
		
		try 
		{
			// TransactionManagerを取得
			InitialContext context = new InitialContext();
			tm = (TransactionManager)context.lookup("java:/TransactionManager");
			
			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避 
			if(tm.getTransaction() != null){
				oldTx = tm.suspend();
			}
			
			try{
				// トランザクション開始
				if(tm.getTransaction() == null){
					tm.begin();	
//					tx = tm.getTransaction();
				}
				
				// 監視情報を登録
				result = addMonitorInfo(user);
				if(result){
					// コミット
//					tx.commit();
					tm.commit();
				}
				
				try {
					// 更新通知
					UpdateSnmpTrapInfo updateInfo = new UpdateSnmpTrapInfo(
							UpdateSnmpTrapInfo.TYPE_ADD,
							info.getMonitorId());
					
					SendTopic sendTopic = new SendTopic(TopicConstant.TOPIC_NAME_UPDATE);
					sendTopic.put(updateInfo);
					
				} catch (NamingException e) {
					m_log.error("add() : 送信エラー。" + e.getMessage() );
				} catch (JMSException e) {
					m_log.error("add() : 送信エラー。" + e.getMessage() );
				}
			
			} catch(NotSupportedException e){
				outputLog(e, "add()");
				throw e;
			} catch (RollbackException e) {
				outputLog(e, "add()");
				throw e;
			} catch (HeuristicMixedException e) {
				outputLog(e, "add()");
				throw e;
			} catch(HeuristicRollbackException e){
				outputLog(e, "add()");
				throw e;
			} catch(SystemException e){
				outputLog(e, "add()");
				throw e;
			}
			finally{
				// トランザクション関連の例外が発生した場合は、ロールバック
//				if(tx != null){
//					if(!result){
//						tx.rollback();
//					}
//					tx = null;
//				}
				if(tm.getTransaction() != null){
					if(!result){
						tm.rollback();
					}
				}
			}
		}
		finally{
			
			// 一時停止していたトランザクションを再開
			if(oldTx != null){
				try{
					tm.resume(oldTx);
				
				} catch(InvalidTransactionException e){
					outputLog(e, "add()");
					throw e;
				} catch(IllegalStateException e){
					outputLog(e, "add()");
					throw e;
				} catch(SystemException e){
					outputLog(e, "add()");
					throw e;
				}
			}
		}
		return result;
	}

	/**
	 * 監視情報を登録します。<BR>
	 * 
	 * @param user ユーザ
	 * @return 登録に成功した場合、true
	 * @throws CreateException
	 * @throws NamingException
	 * @throws FinderException 
	 */
	public boolean addMonitorInfo(String user) throws CreateException, NamingException, FinderException {
		boolean result = false;
		
		try 
		{
			Timestamp now = new Timestamp(new Date().getTime());
			
			m_log.trace("addMonitorInfo  : m_monitorInfo.getCheckMode() " + m_monitorInfo.getCheckMode());
			// 監視情報を挿入
			SnmpTrapInfoUtil.getLocalHome().create(
					m_monitorInfo.getMonitorId(),
					m_monitorInfo.getDescription(),
					m_monitorInfo.getFacilityId(),
					m_monitorInfo.getCommunityName(),
					m_monitorInfo.getApplication(),
					m_monitorInfo.getValid(),
					m_monitorInfo.getCalendarId(),
					m_monitorInfo.getNotifyGroupId(),
					now,
					now,
					user,
					user,
					m_monitorInfo.getCheckMode()
			);
			
			
			// ジョブ連携のため追加
			// 重要度ごとに実行するジョブの情報を保持するテーブルが必要だが、
			// SNMPトラップ監視機能の設定情報を保持するテーブル cc_snmp_trap_info には、
			// ジョブ連携用の情報を保持するカラムがないため、cc_monitor_infoテーブルと
            // cc_monitor_numeric_value_infoテーブルにその情報を保持する。
			MonitorInfoUtil.getLocalHome().create(
					m_monitorInfo.getMonitorTypeId(),
					m_monitorInfo.getMonitorId(),
					m_monitorInfo.getMonitorType(),
					m_monitorInfo.getDescription(),
					m_monitorInfo.getFacilityId(),
					m_monitorInfo.getRunInterval(),
					m_monitorInfo.getTimeout(),
					m_monitorInfo.getCalendarId(),
					m_monitorInfo.getMonitorBlock(),
					m_monitorInfo.getDeterminationId(),
					m_monitorInfo.getFailurePriority(),
					m_monitorInfo.getApplication(),
					m_monitorInfo.getFailureMessageId(),
					m_monitorInfo.getFailureMessage(),
					m_monitorInfo.getNotifyGroupId(),
					now,
					now,
					user,
					user
					
			);
			
			//通知情報を投入
			if(m_monitorInfo.getNotifyGroupId() != null){
				
				NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
				
				nc.addNotifyRelation(m_monitorInfo.getNotifyId());
			}
			
		/*	ArrayList valueList = m_monitorInfo.getJudgementInfo();
			MonitorNumericValueInfo value = null;
			for(int index=0; index<valueList.size(); index++){
				value = (MonitorNumericValueInfo)valueList.get(index);
				if(value != null){
					MonitorNumericValueInfoUtil.getLocalHome().create(
							m_monitorInfo.getMonitorTypeId(),
							m_monitorInfo.getMonitorId(),
							Integer.valueOf(value.getPriority()),
							Double.valueOf(value.getThresholdUpperLimit()),
							Double.valueOf(value.getThresholdLowerLimit()),
							value.getMessageId(),
							value.getMessage());
				}
			}*/
			
			
			
			if(m_monitorInfo.getOidInfos() != null){
				
				for(int i = 0; i < m_monitorInfo.getOidInfos().size(); i++){
					MonitorSnmpTrapOidInfo oidInfo = m_monitorInfo.getOidInfos().get(i);
					
					SnmpTrapMasterLocal master = 
						SnmpTrapMasterUtil.getLocalHome().findByPrimaryKey(
							new SnmpTrapMasterPK(
									oidInfo.getMib(), 
									oidInfo.getTrapOid(), 
									oidInfo.getGenericId(), 
									oidInfo.getSpecificId()));
					
					//詳細メッセージをマスタの詳細メッセージと比較
					String descr = new String();
					if(oidInfo.getDescr() != null && master.getDescr() != null && 
							!oidInfo.getDescr().equalsIgnoreCase(master.getDescr())){
						if(!oidInfo.getDescr().equalsIgnoreCase(master.getDescr())){
							descr = oidInfo.getDescr();
						}
					}
					else{
						descr = oidInfo.getDescr();
					}
					
					// 監視OID情報を挿入
					SnmpTrapOidInfoUtil.getLocalHome().create(
							oidInfo.getMonitorId(),
							oidInfo.getMib(),
							oidInfo.getTrapOid(),
							new Integer(oidInfo.getGenericId()),
							new Integer(oidInfo.getSpecificId()),
							new Integer(oidInfo.getValidFlg()),
							new Integer(oidInfo.getPriority()),
							oidInfo.getLogmsg(),
							descr
					);
				}
			}
				
			result = true;
			
		} catch (CreateException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		} catch (NamingException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		} catch (FinderException e) {
			outputLog(e, "addMonitorInfo()");
			throw e;
		}
		
		return result;
	}
	
	/**
     * アプリケーションログにログを出力
     * 
     * @param e 例外
     */
	private void outputLog(Exception e, String method){
		AplLogger apllog = new AplLogger("TRAP", "trap");
		String[] args = {m_monitorInfo.getMonitorId() };
        apllog.put("SYS", "001", args);
        m_log.debug(method + ":" + e.getMessage());
	}
}
